package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchDues;

/**
 * 支部党费收支管理Service接口
 * 
 * @author ruoyi
 * @date 2023-07-14
 */
public interface ITBranchDuesService 
{
    /**
     * 查询支部党费收支管理
     * 
     * @param duesId 支部党费收支管理主键
     * @return 支部党费收支管理
     */
    public TBranchDues selectTBranchDuesByDuesId(Long duesId);

    /**
     * 查询支部党费收支管理列表
     * 
     * @param tBranchDues 支部党费收支管理
     * @return 支部党费收支管理集合
     */
    public List<TBranchDues> selectTBranchDuesList(TBranchDues tBranchDues);

    /**
     * 新增支部党费收支管理
     * 
     * @param tBranchDues 支部党费收支管理
     * @return 结果
     */
    public int insertTBranchDues(TBranchDues tBranchDues);

    /**
     * 修改支部党费收支管理
     * 
     * @param tBranchDues 支部党费收支管理
     * @return 结果
     */
    public int updateTBranchDues(TBranchDues tBranchDues);

    /**
     * 批量删除支部党费收支管理
     * 
     * @param duesIds 需要删除的支部党费收支管理主键集合
     * @return 结果
     */
    public int deleteTBranchDuesByDuesIds(Long[] duesIds);

    /**
     * 删除支部党费收支管理信息
     * 
     * @param duesId 支部党费收支管理主键
     * @return 结果
     */
    public int deleteTBranchDuesByDuesId(Long duesId);
}
